@@ -457,6 +457,10 @@ struct config_options *parse_command_line(char **argv)
         }
       }
 
+      // FIX: 28-Aug-2016
+      if (ptbl->has_arg && !next_str)
+        fatal_error("option '%s' must have an argument.", opt);
+
       set_config_option(&co, opt, ptbl->id, next_str);
     }
     else
@@ -1924,7 +1928,7 @@ int get_dual_values(char *arg,
   /* Error handling... */
   if (setjmp(jb))
   {
-    error("'%s' should be formated as 'n%s'.", optname, optional ? "[.n]" : ".n");
+    error("'%s' should be formatted as 'n%s'.", optname, optional ? "[.n]" : ".n");
     return -1;
   }
 
